超脱 (豆瓣)
Description: 超脱电影简介和剧情介绍,超脱影评、图片、预告片、影讯、论坛、在线购票
Keywords: 超脱,Detachment,超脱影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.91豆瓣电影Top250

# 超脱 Detachment (2011)

导演: 托尼·凯耶
编剧: 卡尔·隆德
主演: 艾德里安·布洛迪 / 马西娅·盖伊·哈登 / 詹姆斯·肯恩 / 克里斯蒂娜·亨德里克斯 / 刘玉玲 / 布莱思·丹纳 / 蒂姆·布雷克·尼尔森 / 威廉·彼德森 / 布莱恩·科兰斯顿 / 萨米·盖尔 / 路易斯·佐里奇 / 小伊塞亚·维特洛克 / 大卫·豪森 / 约翰·塞纳迭姆博 / 西莉亚·奥 / 罗南·鲁宾斯坦 / 阿尔·卡尔德隆 / 布雷南·布朗 / 里根·利奥纳德 / 詹姆斯·霍西 / 乔什·帕斯 / 瑞内·菲利斯·史密斯 / 道格·伊·道格 / 帕特里夏·雷 / 萨曼萨·罗根 / 拉尔夫·罗德里格斯
类型: 剧情
官方网站: detachment-film.com
制片国家/地区: 美国
语言: 英语
上映日期: 2011-04-25(翠贝卡电影节)
片长: 98分钟
又名: 人间师格(台)
IMDb: tt1683526
豆瓣评分
引用
9.0
545232人评价
5星
58.5%
4星
33.2%
3星
7.5%
2星
0.7%
1星
0.2%
好于 98% 剧情片
想看 看过
评价:
推荐

## 超脱的剧情简介 · · · · · ·

亨利•巴赫特（艾德里安•布洛迪 Adrien Brody 饰）来到社区学校担任代课老师。学校因学生反叛、经营不善而濒临绝境，多丽丝（刘玉玲 饰）为首的一批教师备受煎熬。亨利的第一堂课就遭遇了顽劣学生的挑衅，但是被他巧妙地化解。他赢得了女教师萨沙（克里斯蒂娜•亨德里克斯 Christina Hendricks）的好感。同时，他的教学方式引起了同学们的兴趣，其中就包括因肥胖而苦闷的梅丽迪斯。她一直默默地承受着因体重带来的各种责骂与嘲笑。但是因为老师，她似乎又找到了一切的理由……
但是，亨利其实内心也有很大的压力，他的爷爷处于弥留之际，他的母亲自杀阴影始终在脑海中萦绕。某天夜里，他在公车上黯然神伤，独自流泪。这情形被一个刚受到嫖客凌辱的雏妓艾瑞卡（萨米•盖尔 Sami Gayle 饰）看到了。她尾随他，希望获得他的帮助。他起初拒绝了她的要求，后来他还是把她... (展开全部) 亨利•巴赫特（艾德里安•布洛迪 Adrien Brody 饰）来到社区学校担任代课老师。学校因学生反叛、经营不善而濒临绝境，多丽丝（刘玉玲 饰）为首的一批教师备受煎熬。亨利的第一堂课就遭遇了顽劣学生的挑衅，但是被他巧妙地化解。他赢得了女教师萨沙（克里斯蒂娜•亨德里克斯 Christina Hendricks）的好感。同时，他的教学方式引起了同学们的兴趣，其中就包括因肥胖而苦闷的梅丽迪斯。她一直默默地承受着因体重带来的各种责骂与嘲笑。但是因为老师，她似乎又找到了一切的理由……
但是，亨利其实内心也有很大的压力，他的爷爷处于弥留之际，他的母亲自杀阴影始终在脑海中萦绕。某天夜里，他在公车上黯然神伤，独自流泪。这情形被一个刚受到嫖客凌辱的雏妓艾瑞卡（萨米•盖尔 Sami Gayle 饰）看到了。她尾随他，希望获得他的帮助。他起初拒绝了她的要求，后来他还是把她带回了单身公寓…… ©豆瓣

## 超脱的演职员 · · · · · · ( 全部 39 )

- 托尼·凯耶 导演
- 艾德里安·布洛迪 饰 Henry Barthes
- 马西娅·盖伊·哈登 饰 Principal Carol Dearden
- 詹姆斯·肯恩 饰 Mr. Charles Seaboldt
- 克里斯蒂娜·亨德里克斯 饰 Ms. Sarah Madison
- 刘玉玲 饰 Dr. Doris Parker

## 超脱的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片1033 · 添加 )

## 超脱的获奖情况 · · · · · · ( 全部 )

- 第24届东京国际电影节
- 主竞赛单元 最佳影片(提名)
- 托尼·凯耶

- 第24届东京国际电影节
- 主竞赛单元 最佳艺术贡献奖
- 托尼·凯耶

- 第3届豆瓣电影鑫像奖
- 鑫豆单元 最佳影片(外语)(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  一一

  重庆森林

  花样年华

  阿飞正传

  布达佩斯大饭店

  爱在黎明破晓前

  海上钢琴师

  天使爱美丽

  海边的曼彻斯特

  霸王别姬

我要写短评

## 超脱的短评 · · · · · · ( 全部 152864 条 )

热门 / 最新 / 好友

### 16048 有用 亚比煞 看过 2012-06-03 14:00:11

少年时，我们都自私无知，夸张那些伤痛来当作放纵的借口。只知依赖不知自救，只知索取不知珍惜。打架，滥交，还自以为是看透了生命，绝望的很酷，其实肤浅的令人发指。孩子，什么时候你开始沉默的承受加诸你身上的重量，尊重它并与它和平相处，你才真的能称为一个大写的人。

### 6227 有用 柏林苍穹下 看过 2012-05-05 23:29:51

“我的灵魂与我之间的距离如此遥远，而我的存在却如此真实。”——加缪

### 9215 有用 linsang 看过 2012-06-02 19:45:40

这是一部不推荐看的好电影。没病的都要看出病的。好的作品分两种，一是发现世界的极美，二是挖掘人间的极苦。这部就是后者。

### 6051 有用 匡轶歌 看过 2012-04-26 21:56:43

一次次泪倾，哭到胸口抽痛、难以呼吸。当我们感到需要暖意，首先要学会的，是彼此拥抱。穷尽一生，我们要学会的，不过是彼此拥抱。只因“一个人可以轻易地学会不在乎，但学会在乎，却要付出百倍的努力和勇气”，再不要独自一人穿过灰暗暝寂的暮色，在摇摇欲坠之前，在生命荒芜心脏冷却之前，彼此拥抱。

### 2274 有用 LORENZO 洛伦佐 看过 2012-03-09 16:31:46

每个人的内心都是一座孤岛，人的心有多深，深到让别人无法试探的地步？教育和生活其实一样，教育者既可以超然物外，也可以放下防备与被教育者心灵交互。讽刺的却是，超脱既可以赢来尊敬，也一样能扼杀心灵。Adrien Brody终于跳出了烂片的泥潭，用忧郁气质和演技，再次将人性的考量重重甩在了观众脸上。

> 更多短评 152864条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 超脱的影评 · · · · · · ( 全部 3224 条 )

热门 / 最新 / 好友
Joshua|蓝牙君 2012-05-10 22:17:41

## 这不是一篇影评

我是一所民办大学的老师，水平不高，时间不长，学生不多，学校不好，待遇不高。 这里的学生分划很严重，有钱的上学开着凯迪拉克，没钱的学生直到毕业都交不齐学费。学校里有女生去做援交，每个周五的晚上坐着门口的黑车去三里屯的酒店上班。学校里有精神有疾病的少年，每天背着... (展开)
14606 255 674回应 收起
ladygangcha 2012-05-12 06:58:55

## 男猪脚的第二次发火

这篇影评可能有剧透

我连夜看了两遍！ 你们是否记得一个细节就是在胖女孩在向老师倾诉自己的内心时，漂亮的女老师进来看见他们相互拥抱。镜头切换很快。 此时，女人内心是愚蠢的。她不停的质问。 而内心极度敏感的男猪脚，却因这质问大发雷霆。注意：男猪脚平时性情很温和，第一次发火是在外公把... (展开)
12973 706 1326回应 收起
CharlesChou 2012-03-01 16:59:35

## 中英字幕，结尾爱伦·坡的小说文段以及影评

这篇影评可能有剧透

昨天英文的字幕出了 但是看了一下，制作者应该没读过爱伦·坡的《厄舍府的倒塌》，前面都没有大问题，但结尾部分错漏百出，utter变成了other，sickening变成seeking，连写在黑板上的Usher都能变成Russia，实在是接受不能... ================== 4.22 把中英字幕做了，顺便修正... (展开)
5145 151 176回应 收起
feifeiRun 2012-05-02 02:54:45

## 局外人的爱

小说家加缪这样说：“母亲死了，我一滴泪也掉不出来..."，亨利和他所处的环境，和他的家庭，甚至和他的自身也落入了同样孤绝的境地。 Detachment，亦即绝对孤立，和一切脱离了联系。 影片毫不避讳地把亨利放在局外人的位置，代课教师的身份也如此明白昭彰，他甚至不需要和学生... (展开)
2041 84 147回应 收起
SingLesinger 2011-10-28 23:39:14

## Detachment

这篇影评可能有剧透

If you are or feel screwed and fucked up on a daily basis. If you are suicidal, or you were at some point of your life. If you are fascinated with the everlasting melancholic touch on Adrian Brody's sculptured face. If you read Edgar Allan Poe and love i... (展开)
1819 92 178回应 收起
仲曰 2012-05-30 12:27:12

## 关于Henry

【局外人•存在感】 影片开篇引用存在主义哲学、文学家——加缪的一句话——“我的灵魂与我之间的距离如此遥远，而我的存在却如此真实。”——毫无疑问，这句话几乎可以阐明整部影片的情感基调——孤独感。 影片是以伪纪录片的形式讲述了Henry的一些琐碎的背后却具有连贯性的... (展开)
2450 18 96回应 收起
巴斯特德 2012-05-06 02:43:17

## 现实与自我的枷锁

And never have I felt so deeply at one and the same time So detached from myself and so present in the world. -----------------------加缪 这是一部有关人生苦痛的电影，无法割裂的自我与现实世界，交织在一起，让我们在那些想要拯救，想要寻求救赎的瞬间，感觉到无比... (展开)
1090 31 65回应 收起
甘樂 2012-05-09 09:17:59

## 刘玉玲的话。

-What are your plan for after high school ever since you will not go to college? -I dont know. hanging out with my boyfriend, do some modelling shit, be in my friends' band. -I have your ten of your scores report, do you know what is says? F, F, F, F. -F, F... (展开)
625 17 40回应 收起
3❤22 2012-05-09 06:46:06

## 记录台词

During the whole of a dull,dark soundless day 　　在那年秋季枯燥，灰暗而瞑寂的某个长日里 　　 　　In the autumn of that year, when the clouds hung oppressively low in heaven 　　沉重的云层低悬于天穹之上 　　 　　I had been passing alone on the horse's... (展开)
732 8 32回应 收起
袁长庚 2013-01-05 22:09:41

## 人间的教养

这篇影评可能有剧透

我不安地瞥了一眼时间轴，还有二十分钟结束，《放牛班的春天》是不可能了，但巴望导演不必关闭这所学校，不必撤换校长，不必让胖乎乎的女生死，不必让老师最终走掉…… 还有很多的“不必”。这好比是纯净的“人间”的梦想：老师应当带领我们找到灵魂，童年的废墟上应当有金色... (展开)
446 16 26回应 收起

> 更多影评 3224篇

添加新讨论

## 讨论区 · · · · · ·

无病呻吟的电影 | 来自鸽王 | 437 回应 | 2022-11-24 17:24:12
我想知道男主的妈妈究竟为什么自杀 | 来自雅玛图 | 29 回应 | 2022-11-20 19:10:24
想问问大家男主背的这种包叫啥呀 | 来自Zoë | 4 回应 | 2022-11-13 20:38:20
哪个视频网站的版本好一点求问 | 来自自此远遁江湖 | 2 回应 | 2022-11-08 19:45:34
想要戒指 | 来自啊噗啊呸 |  | 2022-11-07 02:16:23

> 去这部影片的讨论区（全部408条）

## 关于《超脱》的问题 · · · · · · ( 全部47个 )

- 男主角为什么开始送走雏妓艾瑞卡，而后又去领养她？ 19人回答
- 男主的母亲和爷爷究竟是怎么回事？ 29人回答

> 全部47个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 免费观看
- 西瓜视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 125部反类型片 (远山近海)
- 2011新电影（这些，可以期待） (桃桃林林)
- 极品电影 (waking forest)
- 2012 豆瓣电影【口碑榜】 (影志)

## 谁在看这部电影 · · · · · ·

- Corning
  5分钟前 看过
- LookAtTheStar
  7分钟前 想看
- 纱织NaNa
  7分钟前 看过

737033人看过 / 440906人想看

订阅超脱的评论:
feed: rss 2.0